# package does not work in F26 because openssl-devel is 1.1 version
# but Qt has been built against OpenSSL 1.0 version, so qesteidutil will crash
# Therefore this spec file is for Fedora >= 27 only

Name:           qdigidoc
Version:        3.13.4
Release:        2%{?dist}
Summary:        Estonian digital signature application
License:        LGPLv2+
URL:            https://github.com/open-eid/qdigidoc
Source0:        %{url}/releases/download/v%{version}/%{name}-%{version}.tar.gz
Source1:        EE.xml
Source2:        config.json
Source3:        config.pub
Source4:        config.rsa
Source5:        config.qrc
Source6:        TSL.qrc
Source7:        tl-mp.xml

Patch0:         sandbox-compilation.patch
Patch1:         remove_crypto_appdata.patch


BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  gettext
BuildRequires:  libdigidocpp-devel
BuildRequires:  openldap-devel
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(Qt5Designer)
BuildRequires:  pkgconfig(libpcsclite) >= 1.7
BuildRequires:  libappstream-glib
BuildRequires:  qtsingleapplication-qt5-devel
Requires:       hicolor-icon-theme
# Dynamically loaded library
Requires:       opensc%{?_isa}
Requires:       pcsc-lite-ccid%{?_isa}
Requires:       liberation-fonts
%description
QDigiDoc is an application for digitally signing and encrypting documents in
ASiC-E, BDoc, DDoc, and CDoc container formats. These file formats are
widespread in Estonia where they are used for storing legally binding digital
signatures.


%package        nautilus
Summary:        Nautilus extension for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       nautilus-python

%description    nautilus
The %{name}-nautilus package contains the %{name} extension for the
nautilus file manager.

%prep
%setup -q
%patch0 -p1
%patch1 -p1

# AUTHORS file is not UTF-8, check if it will still apply for libdigidocpp > 3.13.2
iconv --from=ISO-8859-1 --to=UTF-8 AUTHORS > AUTHORS.new && \
touch -r AUTHORS AUTHORS.new && \
mv AUTHORS.new AUTHORS

cp %{S:1} client/
cp %{S:2} common/
cp %{S:3} common/
cp %{S:4} common/
cp %{S:5} common/
cp %{S:6} client/
cp %{S:7} client/


# Remove bundled qtsingleapplication to make sure it isn't used
rm -rf qtsingleapplication
# Remove appdata file - not needed any more
rm -f crypto/qdigidoc-cypto.appdata.xml


%build
%{cmake} . -DBREAKPAD=FALSE

%make_build

%install
%make_install

desktop-file-validate %{buildroot}/%{_datadir}/applications/qdigidoc-client.desktop
desktop-file-validate %{buildroot}/%{_datadir}/applications/qdigidoc-crypto.desktop

appstream-util validate-relax --nonet %{buildroot}/%{_datadir}/appdata/*.appdata.xml

%find_lang nautilus-qdigidoc

%files
%doc AUTHORS README.md CONTRIBUTING.md RELEASE-NOTES.md
%license COPING LICENSE.LGPL
%{_bindir}/*
%{_datadir}/applications/*.desktop
%{_datadir}/mime/packages/*.xml
%{_datadir}/icons/hicolor/*/*/*.png
%{_datadir}/kde4/services/*.desktop
%{_datadir}/appdata/*.appdata.xml
%{_mandir}/man1/qdigidocclient.1*

%files nautilus -f nautilus-qdigidoc.lang
%{_datadir}/nautilus-python/extensions/*

%changelog
* Thu Jan 18 2018 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 3.13.4-2
- Remove obsolete scriptlets

* Thu Nov 30 2017 Germano Massullo <germano.massullo@gmail.com> - 3.13.4-1
- 3.13.4 release
- added ASiC-E into description

* Mon May 15 2017 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.12.6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_27_Mass_Rebuild

* Fri Feb 24 2017 Mihkel Vain <mihkel@fedoraproject.org> - 3.12.6-1
- New upstream release
- Add openssl v1.1 support via qdigidoc-opensslv1.1.patch
- Manually update config.rsa, config.pub and config.json

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.12.5-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Feb 02 2017 Mihkel Vain <mihkel@fedoraproject.org> - 3.12.5-3
- Bump version number
- Add a patch to remove qdigidoc-cypto.appdata.xml from cmake also.

* Thu Feb 02 2017 Mihkel Vain <mihkel@fedoraproject.org> - 3.12.5-2
- Remove qdigidoc-cypto.appdata.xml file, since it is no longer required.

* Thu Feb 02 2017 Mihkel Vain <mihkel@fedoraproject.org> - 3.12.5-1
- New upstream release

* Mon Jan 23 2017 Mihkel Vain <mihkel@fedoraproject.org> - 3.12.4-1
- New upstream release

* Tue Jan 10 2017 Mihkel Vain <mihkel@fedoraproject.org> - 3.12.3-1
- New upstream release
- Update config.json, config.rsa and config.pub manually, since koji does not
  support networking while building

* Wed Nov 23 2016 Mihkel Vain <mihkel@fedoraproject.org> - 3.12.2-3
- Remove libdigidoc-devel from BuildRequires
- Add requirement for liberation fonts
- Add requirement for pcsc-lite-ccid
- Fix typo in patch name

* Wed Nov 23 2016 Mihkel Vain <mihkel@fedoraproject.org> - 3.12.2-2
- Update tl-mp.xml, config.json, config.rsa, config.pub and EE.xml files, since
  koji will not allow networking during build
- Rename SSL_fix.patch to sanbox-compilation.path
- Remove unused pathces from repo

* Sun Jul 10 2016 Mihkel Vain <mihkel@fedoraproject.org> - 3.12.2-1
- New upstream release

* Tue Jun 07 2016 Mihkel Vain <mihkel@fedoraproject.org> - 3.12.1-2
- BZ#1342789 - Add SSL_fix.patch

* Thu May 19 2016 Mihkel Vain <mihkel@fedoraproject.org> - 3.12.1-1
- New upstream release

* Tue Feb 02 2016 Mihkel Vain <mihkel@fedoraproject.org> - 3.12.0-1
- New upstream release

* Tue Sep 22 2015 Mihkel Vain <mihkel@fedoraproject.org> - 3.11.1.1427-1
- New upstream release
- Drop un-needed patches

* Sat Aug  1 2015 Mihkel Vain <mihkel@fedoraproject.org> - 3.11.0.1416-2
- Tune appdata and desktop file

* Sat Aug  1 2015 Mihkel Vain <mihkel@fedoraproject.org> - 3.11.0.1416-1
- New upstream release
- Spec file cleanups

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.10.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sun Apr 19 2015 Mihkel Vain <mihkel@fedoraproject.org> - 3.10.0-3
- Rebuild for gcc5

* Thu Apr  9 2015 Mihkel Vain <mihkel@fedoraproject.org> - 3.10.0-2
- Force linking to pthread (#1210036)

* Sat Mar 28 2015 Mihkel Vain <mihkel@fedoraproject.org> - 3.10.0-1
- New upstream release
- Project moved to github
- Drop unneeded patches
- Drop qdigidoccrypto man page - there is no such binary anymore

* Tue Nov 18 2014 Dan Horák <dan[at]danny.cz> - 3.9.1.1369-2
- enable internal crash handler only on supported arches

* Sun Oct 26 2014 Mihkel Vain <mihkel@fedoraproject.org> - 3.9.1.1369-1
- New upstream release

* Mon Aug 18 2014 Rex Dieter <rdieter@fedoraproject.org> 3.9.0.1297-4
- update mime scriptlets

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.9.0.1297-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jul  5 2014 Mihkel Vain <mihkel@fedoraproject.org> - 3.9.0.1297-2
- Add appdata support

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.8.1.1250-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Wed Apr 30 2014 Mihkel Vain <mihkel@fedoraproject.org> - 3.8.1.1250-3
- Use cmake macro

* Wed Apr 30 2014 Mihkel Vain <mihkel@fedoraproject.org> - 3.8.1.1250-2
- Obsolete qdigidoc-nautilus
- Change minidump.cc permissions in prep
- Patch right line with 0001-fix-cmake-flags.patch

* Wed Apr 30 2014 Mihkel Vain <mihkel@fedoraproject.org> - 3.8.1.1250-1
- First package based on new source code from RIA

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Apr 17 2012 Kalev Lember <kalevlember@gmail.com> - 0.4.1-1
- Update to 0.4.1
- Include new man pages
- Update the nautilus subpackage files list for Nautilus 3 support
- Make the nautilus subpackage noarch

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Fri Apr 15 2011 Kalev Lember <kalev@smartlink.ee> - 0.4.0-5
- Rebuilt for lib11 0.2.8 soname bump

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Oct 20 2010 Kalev Lember <kalev@smartlink.ee> - 0.4.0-3
- Require hicolor-icon-theme (#642555)

* Wed Oct 13 2010 Kalev Lember <kalev@smartlink.ee> - 0.4.0-2
- Updated summary
- Added missing BR gettext

* Wed Oct 13 2010 Kalev Lember <kalev@smartlink.ee> - 0.4.0-1
- Update to 0.4.0
- Packaged up Nautilus extension and KDE service menu

* Tue May 11 2010 Kalev Lember <kalev@smartlink.ee> - 0.3.0-0.35.svn2682
- BR qt4-webkit-devel (F14+)

* Mon Mar 29 2010 Kalev Lember <kalev@smartlink.ee> - 0.3.0-0.34.svn2682
- Spec file clean up
- Added AUTHORS and COPYING docs
- Cleaned up nightly build changelog entries

* Fri Feb 26 2010 Kalev Lember <kalev@smartlink.ee> - 0.3.0-0.29.svn2542
- rebuilt with Qt 4.6

* Thu Jan 21 2010 Kalev Lember <kalev@smartlink.ee> - 0.3.0-0.25.svn2451
- rebuilt with new libp11

* Sun Jun 14 2009 Kalev Lember <kalev@smartlink.ee> - 0.3.0-0.1.svn713
- Initial RPM release.
